{ inputs, config, pkgs, ... }:
let
    fzgo_paths = [
        "/home/user/.dotfiles"
        "/home/server/.cache/fzgo/entries/d/|home|server|Workspace"
        "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Thomas"
        "/home/server/.cache/fzgo/entries/d/|home|server|Storage|Shared"
    ];
in
{
    imports = [
        (import ./utils/desktop.nix { inherit inputs config pkgs; })
        (import ./utils/fzgo_links.nix { inherit config pkgs fzgo_paths; })
    ];

    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Arendia/id_ed25519";

    home.packages = with pkgs; [
        distrobox
        gnome-disk-utility
        moonlight-qt
        vscode
        texliveFull
        zed-editor
        gnome-power-manager
        jetbrains.pycharm-professional
    ];

    services.hyprpaper = {
        settings = {
            wallpaper = [
                "HDMI-A-1,${./hyprland/files/wallpaper.png}"
                "eDP-1,${./hyprland/files/wallpaper.png}"
            ];
        };
    };

    wayland.windowManager.hyprland.settings = {
        monitor = [
            "eDP-1,2560x1440@60.01,0x0,1.25"
            "HDMI-A-1,1920x1080@60,0x-1080,1"
        ];
        bind = [
            ", XF86PowerOff, exec, ${pkgs.rofi}/bin/rofi -show power-menu -modi power-menu:${
            ./hyprland/files/rofi-power-menu.sh
        }"
        ];
        general.gaps_out = 1;
    };

    programs.alacritty.settings.font.size = 13;
    programs.kitty.font.size = 13;
    programs.zsh.initExtra = pkgs.lib.mkForce ''
      LOCAL_SEARCH_DIRS=(~/.dotfiles/)
      REMOTE_SEARCH_DIRS=( ~/Workspace)
    '';
}
